News from The Associated Press

AP Radio AP Radio News: Your browser does not support the audio element.

Jun 13, 4:03 PM EDT Father of Orlando gunman known for rambling political videos By LYNNE O'DONNELL Associated Press
AP Photo/Uncredited
KABUL, Afghanistan (AP) -- The father of the Orlando nightclub gunman came to the U.S. from Afghanistan more than 30 years ago and has made a series of rambling political videos about his former homeland, even once describing himself as its "revolutionary president." Seddique Mir Mateen maintained a high profile on social media in the U.S., but is a mystery to Afghan authorities. Some government departments ran background and security checks Monday and found no trace of him, an official said. Mateen met with reporters Monday at his home in Port St. Lucie, Florida, and called the massacre by his son, Omar Mateen, "the act of a terrorist." The deadly weekend attack shocked the family, the father said, and went against what he had taught his son. The elder Mateen also said that if he had known what the 29-year-old was planning, he would have arrested him himself. In a Facebook video posted after the killings, Mateen said: "I don't know what caused him to shoot last night." "On the issue of homosexuality, it can be punished only by God, it is not the business of a person. But he (Omar) has killed those people, and I am so saddened," he added. The elder Mateen is a life insurance salesman who started a group in 2010 called Durand Jirga, Inc., according to Qasim Tarin, a businessman from California who was a Durand Jirga board member. The name refers to the Durand Line, the long disputed border established by the British between Afghanistan and Pakistan. He apparently left Afghanistan more than 30 years ago, after the 1979 invasion by the Soviet Union touched off a decade-long war of resistance. A civil war was followed by five years of radical Islamist rule by the Taliban until the U.S. invasion of 2001. Since then, the country has been trying to rebuild, with help from the U.S. and other countries, while the Taliban continue to fight the Kabul government. With constant turnover in government departments in the past 15 years, there appears to be no record of Mateen. Efforts were made to find out about his past, "but we haven't found a clue," according to an official in the Afghan intelligence agency, speaking on condition of anonymity because he was not authorized to talk to reporters. But Kabul-based political analyst Ahmad Saeedi said Mateen, who is about 70, is from the eastern province of Laghman and was living in the capital when he left 31 years ago for the U.S. A fierce anti-communist, Mateen was a captain in the ranks of the mujahedeen who fought the Soviet occupation, Saeedi said. Once in the U.S., he promoted himself to the rank of general. Mateen made a series of videos on social media in the Dari language in which he blamed Afghanistan's ills on a variety of people and organizations, notably Pakistan's intelligence agency, the ISI. The videos were called the "Durand Jirga Show." "For the past three or four years, he has been uploading these videos in which he claims to be the 'revolutionary president' of Afghanistan," Saeedi said. Many of the videos drew only a few hundred views. A former Afghan official said the "Durand Jirga Show" appears on Payam-e-Afghan, a California-based channel that supports ethnic solidarity with the Afghan Taliban, which are mostly Pashtun. The official spoke on condition of anonymity because he did not want to be linked to coverage of the shooting. But video reviewed by The Associated Press on Monday did not show support by Mateen for the Taliban. In an April 2015 video, Mateen said he and his supporters had called on the Taliban to join the peace initiative by current Afghan President Ashraf Ghani. Mateen once had "a brief and inconsequential meeting" with Rep. Ed Royce, the chairman of the House Foreign Affairs Committee, the California Republican said in a statement. Royce said he routinely meets Afghan-Americans and he vaguely recalls a discussion about relations between Afghanistan and Pakistan with Mateen. In a video dated May 23, 2015, Mateen declared himself a candidate for the Afghan presidency. "Afghanistan's sovereignty is in danger due to the free hand of foreigners on our territory, and the result is that 95 percent of the country is not under the government's control," he said, a reference to the influence of Pakistan. "Due to a lack of planning, and resultant economic crisis, I, Seddique Mateen, am declaring myself as a candidate for the presidency in order to rescue Afghanistan." A photo was posted of of a bright green T-shirt depicting him in a black jacket and red tie - the colors of the Afghan flag - and the words: "Seddique Mateen: the real leader of the Afghan people." His Facebook page includes a number of posts introducing "members of our government," showing young men but no biographical information. In another video, he accused President Barack Obama of supporting Pakistan's security agency and urged him to cut off U.S. funding. A YouTube video dated Jan. 11, 2014, showed Mateen interviewing Ghani during his presidential campaign. He deferentially asked Ghani about poverty, unemployment and corruption, and politely allowed the candidate to answer for 13 minutes. But in a video posted Monday on Facebook, Mateen listed senior Afghan officials, including Ghani and former President Hamid Karzai, and he twisted their names to show his disapproval of them. In a repetitive ramble, he called for Afghan unity. Mateen's views on Pakistan's role in Afghanistan reflect those of many Afghan people. Recently, Ghani has publicly blamed Pakistan and its secret service for using the Taliban to wage war on Afghanistan. Pakistan denies the allegations. Ghani's efforts to draw the Taliban into peace talks have failed, with the Taliban saying they have no intention of cooperating. Ghani has also pressured Pakistan to force the Taliban to the table, to no avail. --- Associated Press writers Rahim Faiez, Karim Sharifi and Mirwais Khan in Kabul, and Mitch Weiss in Greenville, South Carolina, contributed to this story. © 2016 The Associated Press. All rights reserved. This material may not be published, broadcast, rewritten or redistributed. Learn more about our Privacy Policy and Terms of Use.

Latest News

Advertisement

©2015 The Associated Press.
All rights reserved. Terms under which this site is provided.
Learn more about our Privacy Policy.